@@ -20,7 +20,7 @@
 
 use 5.014_001;
 
-package Term::CLI::Role::ArgumentSet  0.04005 {
+package Term::CLI::Role::ArgumentSet  0.04006 {
 
 use Modern::Perl 1.20140107;
 
@@ -30,7 +30,7 @@ use Types::Standard 1.000005 qw(
     Maybe
 );
 
-use Moo::Role 1.006001;
+use Moo::Role;
 use namespace::clean 0.25;
 
 has _arguments => (
@@ -98,7 +98,7 @@ Term::CLI::Role::ArgumentSet - Role for (sub-)commands in Term::CLI
 
 =head1 VERSION
 
-version 0.04005
+version 0.04006
 
 =head1 SYNOPSIS
 
