@@ -20,7 +20,7 @@
 
 use 5.014_001;
 
-package Term::CLI::Role::HelpText  0.04005 {
+package Term::CLI::Role::HelpText  0.04006 {
 
 use Modern::Perl 1.20140107;
 
@@ -29,7 +29,7 @@ use Types::Standard 1.000005 qw(
     Str
 );
 
-use Moo::Role 1.006001;
+use Moo::Role;
 use namespace::clean 0.25;
 
 requires 'options';
@@ -204,7 +204,7 @@ Term::CLI::Role::HelpText - Role for generating help text in Term::CLI
 
 =head1 VERSION
 
-version 0.04005
+version 0.04006
 
 =head1 SYNOPSIS
 
